@@ -2,12 +2,15 @@ pub mod activity;
 pub mod comment;
 pub mod comment_report;
 pub mod community;
+pub mod community_block;
 pub mod local_user;
 pub mod moderator;
 pub mod password_reset_request;
 pub mod person;
+pub mod person_block;
 pub mod person_mention;
 pub mod post;
 pub mod post_report;
 pub mod private_message;
+pub mod secret;
 pub mod site;
